@@ -40,12 +40,29 @@ f Spnl Tp wll jst hv t pdt thr trmnls wth nk.
 
 Rck n!
 
-=head1 THRSHP:
+=head1 BUGS AND SOURCE
 
-  Acme::Umlautify v1.01 2004/04/07
+	Bug tracking for this module: https://rt.cpan.org/Dist/Display.html?Name=ACME-Umlautify
 
-  (c) 2004, Phillip Pollard <bennie@cpan.org>
-  Released under the mst xcllnt Perl Artistic License
+	Source hosting: http://www.github.com/bennie/perl-ACME-Umlautify
+
+=head1 VERSION
+
+	Acme::Umlautify v1.03 (DATETAG)
+
+=head1 COPYRIGHT
+
+	(c) 2004-2014, Phillip Pollard <bennie@cpan.org>
+
+=head1 LICENSE
+
+Released under the mst xcllnt Perl Artistic License
+
+This source code is released under the "Perl Artistic License 2.0," the text of
+which is included in the LICENSE file of this distribution. It may also be
+reviewed here: http://opensource.org/licenses/artistic-license-2.0
+
+=head1 THRSHP
 
   ddtnl blm (fr th d) gs t:
   Kristina Davis <krd@menagerie.tf>
@@ -54,7 +71,7 @@ Rck n!
 =cut
 
 package Acme::Umlautify;
-$Acme::Umlautify::VERSION = '1.01';
+$Acme::Umlautify::VERSION = '1.03';
 
 require Exporter;
 require DynaLoader;
